@@ -39,6 +39,8 @@
 #include "config.h"
 #include "conversationmodel.h"
 #include "filehelper.h"
+#include "followrequestmodel.h"
+#include "languagemodel.h"
 #include "linkpaginatedtimelinemodel.h"
 #include "maintimelinemodel.h"
 #include "networkaccessmanagerfactory.h"
@@ -46,6 +48,7 @@
 #include "networkrequestprogress.h"
 #include "notificationmodel.h"
 #include "poll.h"
+#include "polltimemodel.h"
 #include "post.h"
 #include "posteditorbackend.h"
 #include "profileeditor.h"
@@ -72,6 +75,7 @@ int main(int argc, char *argv[])
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
     QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
+    QIcon::setThemeName("tokodon");
 #else
     QApplication app(argc, argv);
     // Default to org.kde.desktop style unless the user forces another style
@@ -134,6 +138,7 @@ int main(int argc, char *argv[])
     qmlRegisterType<MainTimelineModel>("org.kde.kmasto", 1, 0, "TimelineModel");
     qmlRegisterType<LinkPaginationTimelineModel>("org.kde.kmasto", 1, 0, "LinkPaginationTimelineModel");
     qmlRegisterType<SearchModel>("org.kde.kmasto", 1, 0, "SearchModel");
+    qmlRegisterType<FollowRequestModel>("org.kde.kmasto", 1, 0, "FollowRequestModel");
     qmlRegisterType<ThreadModel>("org.kde.kmasto", 1, 0, "ThreadModel");
     qmlRegisterType<ConversationModel>("org.kde.kmasto", 1, 0, "ConversationModel");
     qmlRegisterType<TagsModel>("org.kde.kmasto", 1, 0, "TagsModel");
@@ -142,6 +147,7 @@ int main(int argc, char *argv[])
     qmlRegisterType<NetworkRequestProgress>("org.kde.kmasto", 1, 0, "NetworkRequestProgress");
     qmlRegisterType<PostEditorBackend>("org.kde.kmasto", 1, 0, "PostEditorBackend");
     qmlRegisterType<NotificationModel>("org.kde.kmasto", 1, 0, "NotificationModel");
+    qmlRegisterType<PollTimeModel>("org.kde.kmasto", 1, 0, "PollTimeModel");
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "Clipboard", new Clipboard);
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "FileHelper", new FileHelper);
     qmlRegisterSingletonType("org.kde.kmasto", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
@@ -151,13 +157,16 @@ int main(int argc, char *argv[])
     qRegisterMetaType<AbstractAccount *>("AbstractAccount*");
     qRegisterMetaType<Identity *>("Identity*");
     qRegisterMetaType<AttachmentEditorModel *>("AttachmentEditorModel*");
+    qRegisterMetaType<Post *>("Post*");
     qRegisterMetaType<Poll *>("Poll*");
+    qRegisterMetaType<Card *>("Card*");
     qRegisterMetaType<QNetworkReply *>("QNetworkReply*");
     qRegisterMetaType<Relationship *>("Relationship*");
     qmlRegisterUncreatableType<Post>("org.kde.kmasto", 1, 0, "Post", "ENUM");
     qmlRegisterUncreatableType<Attachment>("org.kde.kmasto", 1, 0, "Attachment", "ENUM");
     qmlRegisterUncreatableType<Notification>("org.kde.kmasto", 1, 0, "Notification", "ENUM");
     qmlRegisterSingletonType(QUrl("qrc:/content/ui/Navigation.qml"), "org.kde.kmasto", 1, 0, "Navigation");
+    qmlRegisterType<LanguageModel>("org.kde.kmasto", 1, 0, "LanguageModel");
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
@@ -168,6 +177,7 @@ int main(int argc, char *argv[])
 
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Client for the decentralized social network: mastodon"));
+    parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports web+ap: url scheme"));
 
     about.setupCommandLine(&parser);
     parser.process(app);
@@ -182,14 +192,30 @@ int main(int argc, char *argv[])
         return -1;
     }
 
+    if (parser.positionalArguments().length() > 0) {
+        NetworkController::instance().openWebApLink(parser.positionalArguments()[0]);
+    }
+
 #ifdef HAVE_KDBUSADDONS
-    QObject::connect(&service, &KDBusService::activateRequested, &engine, [&engine](const QStringList & /*arguments*/, const QString & /*workingDirectory*/) {
+    QObject::connect(&service, &KDBusService::activateRequested, &engine, [&engine](const QStringList &arguments, const QString & /*workingDirectory*/) {
         const auto rootObjects = engine.rootObjects();
         for (auto obj : rootObjects) {
             auto view = qobject_cast<QQuickWindow *>(obj);
             if (view) {
                 KWindowSystem::updateStartupId(view);
                 KWindowSystem::activateWindow(view);
+
+                if (arguments.isEmpty()) {
+                    return;
+                }
+
+                auto args = arguments;
+                args.removeFirst();
+
+                if (arguments.length() >= 1) {
+                    NetworkController::instance().openWebApLink(args[0]);
+                }
+
                 return;
             }
         }
