@@ -46,13 +46,24 @@ void TagsModel::fillTimeline(const QString &fromId)
     uri.setQuery(q);
     const auto account = m_account;
     const auto hashtag = m_hashtag;
-    m_account->get(uri, true, this, [this, account, hashtag, uri](QNetworkReply *reply) {
-        if (account != m_account || m_hashtag != hashtag) {
-            // Receiving request for an old query
-            setLoading(false);
-            return;
-        }
 
-        fetchedTimeline(reply->readAll());
-    });
+    auto handleError = [this](QNetworkReply *reply) {
+        Q_UNUSED(reply);
+        setLoading(false);
+    };
+
+    m_account->get(
+        uri,
+        true,
+        this,
+        [this, account, hashtag, uri](QNetworkReply *reply) {
+            if (account != m_account || m_hashtag != hashtag) {
+                // Receiving request for an old query
+                setLoading(false);
+                return;
+            }
+
+            fetchedTimeline(reply->readAll());
+        },
+        handleError);
 }
